#!/bin/sh
#
#  This is a sample /etc/dhcpcd.sh script.
#  /etc/dhcpcd.sh script is executed by dhcpcd daemon
#  any time it configures or shuts down interface.
#  The following parameters are passed to dhcpcd.exe script:
#  $1 = HostInfoFilePath, e.g  "/var/lib/dhcpcd/dhcpcd-eth0.info"
#  $2 = "up" if interface has been configured with the same
#       IP address as before reboot;
#  $2 = "down" if interface has been shut down;
#  $2 = "new" if interface has been configured with new IP address;
#
#  Sanity checks

if [ $# -lt 2 ]; then
  logger -s -p local0.err -t dhcpcd.sh "wrong usage"
  exit 1
fi

hostinfo="$1"
state="$2"


DHCPCEVT_LOGFILE=/var/log/dhcpc.log
DHCPCUP_LOGFILE=/var/log/dhcpc.up
DHCPCRENEWAL_LOGFILE=/var/log/dhcpc.renewal
DHCPCDOWN_LOGFILE=/var/log/dhcpc.down


# Reading HostInfo file for configuration parameters
. "${hostinfo}"

case "${state}" in
    up)
    logger -s -p local0.info -t dhcpcd.sh \
    "interface ${INTERFACE} has been configured with old IP=${IPADDR}"
    # Put your code here for when the interface has been brought up with an
    # old IP address here

	# Remove aliasing-IP
	ALIAS_DEV="${INTERFACE}:0"
	/sbin/ifconfig $ALIAS_DEV down

	echo "`date +\"%Y/%m/%d %H:%M:%S\"` dhcpcd: $*" > $DHCPCUP_LOGFILE

	# Make mail-body
	DHCPIP_LOGFILE=/var/log/dhcpip.log
	echo > $DHCPIP_LOGFILE
	echo " New DHCP IP Address : $IPADDR" >> $DHCPIP_LOGFILE
	echo " Interface Device : $INTERFACE" >> $DHCPIP_LOGFILE
	echo >> $DHCPIP_LOGFILE

	MAIL_SUBJECT="New DHCP IP Address"
	MAIL_CFGFILE=/etc/sysconfig/netreport.conf

	/usr/sbin/smail "$MAIL_SUBJECT" "$DHCPIP_LOGFILE" "$MAIL_CFGFILE" &

    ;;

    new)
    logger -s -p local0.info -t dhcpcd.sh \
    "interface ${INTERFACE} has been configured with new IP=${IPADDR}"
    # Put your code here for when the interface has been brought up with a
    # new IP address

	# Remove aliasing-IP
	ALIAS_DEV="${INTERFACE}:0"
	/sbin/ifconfig $ALIAS_DEV down

	echo "`date +\"%Y/%m/%d %H:%M:%S\"` dhcpcd: $*" > $DHCPCUP_LOGFILE

	# Make mail-body
	DHCPIP_LOGFILE=/var/log/dhcpip.log
	echo > $DHCPIP_LOGFILE
	echo " New DHCP IP Address : $IPADDR" >> $DHCPIP_LOGFILE
	echo " Interface Device : $INTERFACE" >> $DHCPIP_LOGFILE
	echo >> $DHCPIP_LOGFILE

	MAIL_SUBJECT="New DHCP IP Address"
	MAIL_CFGFILE=/etc/sysconfig/netreport.conf

	/usr/sbin/smail "$MAIL_SUBJECT" "$DHCPIP_LOGFILE" "$MAIL_CFGFILE" &

    ;;

    down) logger -s -p local0.info -t dhcpcd.sh \
    "interface ${INTERFACE} has been brought down"
    # Put your code here for the when the interface has been shut down
    ;;
esac
exit 0
